aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--config/config.c36
-rw-r--r--src/config.h2
2 files changed, 33 insertions, 5 deletions
diff --git a/src/config.h b/src/config.h
index f051fed..6a4bfa9 100644
--- a/src/config.h
+++ b/src/config.h
@@ -5,10 +5,12 @@ typedef struct {
char real_name[25];
char colors[2];
char channels[5][33];
+ char extra_channels[128];
char alert_type;
char show_ping;
char hide_motd;
char atract_away;
+ char disable_keyclick;
} conf_t;
extern conf_t *conf;
diff --git a/config/config.c b/config/config.c
index ac3ade1..0088675 100644
--- a/config/config.c
+++ b/config/config.c
@@ -15,10 +15,12 @@ conf_t defaults = {
"FujiNetChat User",
{ 0xc0, 0x0c },
{ "#testari8", { 0 }, { 0 }, { 0 }, { 0 } },
- 3, /* alert_type, default = both */
- 0, /* show_ping, default = N */
- 1, /* hide_motd, default = Y */
- 1 /* atract_away, default = Y */
+ { 0 }, /* extra_channels */
+ 3, /* alert_type, default = both */
+ 0, /* show_ping, default = N */
+ 1, /* hide_motd, default = Y */
+ 1, /* atract_away, default = Y */
+ 0, /* disable_keyclick, default = N */
};
char have_dos = 0;
@@ -295,7 +297,7 @@ void list_chans(void) {
void prompt_channels(void) {
char c, d, ok;
- print("\nAutojoin channels in screens.\n\n");
+ print("\nAutojoin channels in screens 3-7.\n\n");
list_chans();
putchar('\n');
@@ -340,6 +342,29 @@ void prompt_channels(void) {
}
}
+void prompt_extra_channels(void) {
+ char r, done;
+
+ print("\nAutojoin channels in screen 1.\n\n");
+ print("Enter up to 3 lines of channel names.\n");
+ print("Use normal Atari editing keys.\n");
+
+ do {
+ print("Channels: \n\n\n\n\x1c\x1c\x1c");
+ r = OS.rowcrs;
+ print(conf->extra_channels);
+ OS.rowcrs = r;
+ OS.colcrs = 0;
+ putchar(CH_CURS_RIGHT);
+ putchar(CH_CURS_LEFT);
+
+ gets(buf);
+ strncpy(conf->extra_channels, buf, 128);
+
+ done = yn("OK", 1);
+ } while(!done);
+}
+
void set_default_config(void) {
memcpy(conf, &defaults, sizeof(conf_t));
}
@@ -387,6 +412,7 @@ void main(void) {
conf->atract_away = yn("Set AWAY on ATRACT", conf->atract_away);
conf->hide_motd = yn("Hide MOTD", conf->hide_motd);
prompt_channels();
+ prompt_extra_channels();
make_url();